@@ -6,15 +6,6 @@ use v5.12;
 use warnings;
 use Graphics::Toolkit::Color::Space qw/min max/;
 
-my $hsv_def = Graphics::Toolkit::Color::Space->new( axis => [qw/hue saturation value/],
-                                                   range => [360, 100, 100], precision => 0,
-                                                    type => [qw/angular linear linear/],
-                                                 # suffix => ['', '%', '%'],
-                                                  );
-
-   $hsv_def->add_converter('RGB', \&to_rgb, \&from_rgb );
-
-
 sub from_rgb {
     my ($r, $g, $b) = @{$_[0]};
     my $vmin = min($r, $g, $b);
@@ -28,7 +19,6 @@ sub from_rgb {
                           : (($r - $g) / $d + 4);
     return ([$h/6, $s, $v]);
 }
-
 sub to_rgb {
     my ($h, $s, $v) = @{$_[0]};
     return ([$v, $v, $v]) if $s == 0;
@@ -46,4 +36,12 @@ sub to_rgb {
     return \@rgb;
 }
 
-$hsv_def;
+Graphics::Toolkit::Color::Space->new (
+      axis => [qw/hue saturation value/],
+     range => [360, 100, 100],
+ precision => 0,
+      type => [qw/angular linear linear/],
+  # suffix => ['', '%', '%'],
+   convert => {RGB => [\&to_rgb, \&from_rgb]},
+);
+
